@@ -27,4 +27,9 @@ class Response:
         }
 
 class LoggerException(Exception):
-    pass
\ No newline at end of file
+    pass
+
+class SystemLog:
+    @staticmethod
+    def print_log(msg):
+        print(msg)
\ No newline at end of file
